PCB Environment: Data Fields - Functions

PCB Environment 2

Loading...
Searching...
No Matches
Here is a list of all functions with links to the structures/unions they belong to:

### - b -

- b() : Parameter
- back() : Path
- base() : WideSegment_25
- bbox() : AShape, CircleEx, Connection, dsn::Path, IsoRectEx, LayoutArea, Path, Point_25, PolygonEx, Track, TriangleEx, Via, WideSegment_25
- bboxAroundComps() : Connection
- bboxTest() : Object
- begin() : GridDirection
- Bool() : Token
- BorrowedRef() : py::BorrowedRef
- boundingRadius() : AShape
- build() : NavGrid
- buriedViasOK() : Net